==> verttice_ui-0.0.150.tar.gz: lib/src/utils/download.dart <==
// 🎯 Dart imports:
import 'dart:convert';
import 'dart:io' as io;
import 'dart:typed_data';

// 🐦 Flutter imports:
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

// 📦 Package imports:
import 'package:path_provider/path_provider.dart';
import 'package:share_plus/share_plus.dart';
import 'package:universal_html/html.dart';
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_models/verttice_models.dart';

// 🌎 Project imports:
import 'package:verttice_ui/src/config/config.dart';

class Download {
  Download._();

  static Future<Uint8List> fileFromTheNetwork(String url) async {
    final response = await HttpRetry().get(
      url,
      responseType: HttpRetryResponseType.bytes,
    );
    if (response.data == null) throw 'Cannot save file';
    return response.data;
  }

  static Future<void> memory({
    required Uint8List data,
    required VFileType fileType,
    String? name,
  }) async {
    await _onBytes(
      bytes: data,
      filename: "${name ?? DateTime.now().toString()}.${fileType.name}",
    );
  }

  static Future<void> asset({
    required String assetPath,
    required VFileType fileType,
    String? name,
  }) async {
    final imageData = await rootBundle.load(assetPath);

    await _onBytes(
      bytes: imageData.buffer.asUint8List(),
      filename: "${name ?? DateTime.now().toString()}.${fileType.name}",
    );
  }

  static Future<void> storage({
    required String path,
    required VFileType fileType,
    String? name,
  }) async {
    final data = await VertticeUIConfig.instance.getStorageData(path: path);
    if (data == null) throw 'Cannot save file';

    await _onBytes(
      bytes: data,
      filename: "${name ?? DateTime.now().toString()}.${fileType.name}",
    );
  }

  static Future<void> network({
    required String url,
    required VFileType fileType,
    String? name,
  }) async {
    final response = await fileFromTheNetwork(url);

    await _onBytes(
      bytes: response,
      filename:
          "${name ?? Dates.formatDataAndTime(milliseconds: DateTime.now().millisecondsSinceEpoch)}.${fileType.name}",
    );
  }
}

_onBytes({
  required String filename,
  required Uint8List bytes,
}) async {
  if (kIsWeb) {
    filename = filename.replaceAll('/', '_').replaceAll('\\', '_');
    final base64 = base64Encode(bytes);
    final anchor =
        AnchorElement(href: 'data:application/octet-stream;base64,$base64')
          ..target = 'blank';
    anchor.download = filename;
    document.body?.append(anchor);
    anchor.click();
    anchor.remove();
  } else {
    io.Directory tempDir = await getTemporaryDirectory();
    String tempPath = tempDir.path;
    final file = io.File("$tempPath/$filename");
    await file.writeAsBytes(bytes);
    await Share.shareFiles(
      ["$tempPath/$filename"],
      text: filename,
      subject: "Share a file",
    );
    await file.delete();
  }
}

==> verttice_ui-0.0.153.tar.gz: lib/src/utils/download.dart <==
// 🎯 Dart imports:
import 'dart:convert';
import 'dart:io' as io;
import 'dart:typed_data';

// 🐦 Flutter imports:
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

// 📦 Package imports:
import 'package:path_provider/path_provider.dart';
import 'package:share_plus/share_plus.dart';
import 'package:universal_html/html.dart';
import 'package:verttice_logic/verttice_logic.dart';
import 'package:verttice_models/verttice_models.dart';

// 🌎 Project imports:
import 'package:verttice_ui/src/config/config.dart';

class Download {
  Download._();

  static Future<Uint8List> fileFromTheNetwork(String url) async {
    final response = await HttpRetry().get(
      url,
      responseType: HttpRetryResponseType.bytes,
    );
    if (response.data == null) throw 'Cannot save file';
    return response.data;
  }

  static Future<void> memory({
    required Uint8List data,
    required VFileType fileType,
    String? name,
  }) async {
    await _onBytes(
      bytes: data,
      filename: "${name ?? DateTime.now().toString()}.${fileType.name}",
    );
  }

  static Future<void> asset({
    required String assetPath,
    required VFileType fileType,
    String? name,
  }) async {
    final imageData = await rootBundle.load(assetPath);

    await _onBytes(
      bytes: imageData.buffer.asUint8List(),
      filename: "${name ?? DateTime.now().toString()}.${fileType.name}",
    );
  }

  static Future<void> storage({
    required String path,
    required VFileType fileType,
    String? name,
  }) async {
    final data = await VertticeUI.instance.getStorageData(path: path);
    if (data == null) throw 'Cannot save file';

    await _onBytes(
      bytes: data,
      filename: "${name ?? DateTime.now().toString()}.${fileType.name}",
    );
  }

  static Future<void> network({
    required String url,
    required VFileType fileType,
    String? name,
  }) async {
    final response = await fileFromTheNetwork(url);

    await _onBytes(
      bytes: response,
      filename:
          "${name ?? Dates.formatDataAndTime(milliseconds: DateTime.now().millisecondsSinceEpoch)}.${fileType.name}",
    );
  }
}

_onBytes({
  required String filename,
  required Uint8List bytes,
}) async {
  if (kIsWeb) {
    filename = filename.replaceAll('/', '_').replaceAll('\\', '_');
    final base64 = base64Encode(bytes);
    final anchor =
        AnchorElement(href: 'data:application/octet-stream;base64,$base64')
          ..target = 'blank';
    anchor.download = filename;
    document.body?.append(anchor);
    anchor.click();
    anchor.remove();
  } else {
    io.Directory tempDir = await getTemporaryDirectory();
    String tempPath = tempDir.path;
    final file = io.File("$tempPath/$filename");
    await file.writeAsBytes(bytes);
    await Share.shareFiles(
      ["$tempPath/$filename"],
      text: filename,
      subject: "Share a file",
    );
    await file.delete();
  }
}
